soia library

Classes

ArrayDescriptor
🪞 Describes an array type.
BoolDescriptor
🪞 Describes the bool primitive type.
BytesDescriptor
🪞 Describes the bytes primitive type.
ByteString
An immutable array of bytes.
EnumConstantField
🪞 Describes an enum constant field.
EnumDescriptor
🪞 Describes a Soia enum.
EnumField
🪞 Describes a field in an enum.
EnumSerializer<Enum>
Specialization of a Serializer for generated enum types.
EnumWrapperField
🪞 Describes an enum wrapper field.
Field
🪞 Describes a field in a struct or an enum.
Float32Descriptor
🪞 Describes the float32 primitive type.
Float64Descriptor
🪞 Describes the float64 primitive type.
Int32Descriptor
🪞 Describes the int32 primitive type.
Int64Descriptor
🪞 Describes the int64 primitive type.
internal__EnumSerializerBuilder<Enum>
internal__MutableList<E>
internal__StructSerializerBuilder<Frozen, Mutable>
internal__UnrecognizedEnum
internal__UnrecognizedFields
KeyedIterable<E, K>
An immutable iterable that supports fast lookup by key through findByKey.
Method<Request, Response>
Represents a remote procedure call (RPC) method definition.
NoopReflectiveTypeVisitor<T>
🪞 A no-op implementation of ReflectiveTypeVisitor that does nothing for each visit method.
OptionalDescriptor
🪞 Describes an optional type that can hold either a value of the wrapped type or null.
PrimitiveDescriptor<T>
🪞 Describes a primitive Soia type.
RawResponse
Raw response returned by the server.
RecordDescriptor<F extends Field>
🪞 Describes a record type (struct or enum).
ReflectiveArrayDescriptor<E, Collection extends Iterable<E>>
🪞 Describes an array type.
ReflectiveEnumConstantField<E>
🪞 Describes an enum constant field.
ReflectiveEnumDescriptor<E>
🪞 Describes a Soia enum.
ReflectiveEnumField<E>
🪞 Describes a field in an enum.
ReflectiveEnumWrapperField<E, Value>
🪞 Describes an enum wrapper field.
ReflectiveOptionalDescriptor<NotNull>
🪞 Describes an optional type that can hold either a value of the wrapped type or null.
ReflectiveRecordDescriptor<T, F extends Field>
🪞 Describes a Soia record: struct or enum.
ReflectiveStructDescriptor<Frozen, Mutable>
🪞 Describes a Soia struct.
ReflectiveStructField<Frozen, Mutable, Value>
🪞 Describes a field in a struct.
ReflectiveTransformer
🪞 A function object that takes in a Soia value of any type and returns a new value of the same type.
ReflectiveTypeDescriptor<T>
🪞 Base class for reflective type descriptors that provide runtime type information.
ReflectiveTypeVisitor<T>
🪞 Visitor for performing type-specific reflective operations on Soia types.
RemoteMethodWrapper<Request, Response>
A wrapper around a remote service method that provides invocation.
Serializer<T>
Converts objects of type T to and from JSON or binary format.
Serializers
Provides serializers for all primitive types and utilities for creating composite serializers such as optional and iterable serializers.
Service<RequestMeta>
Implementation of a Soia RPC service that handles incoming requests.
ServiceBuilder<RequestMeta>
Builder for constructing a Service instance with method implementations.
ServiceClient
Sends RPCs to a soia service.
StringDescriptor
🪞 Describes the string primitive type.
StructDescriptor
🪞 Describes a Soia struct.
StructField
🪞 Describes a field in a struct.
StructSerializer<Frozen, Mutable>
Specialization of a Serializer for generated struct types.
TimestampDescriptor
🪞 Describes the timestamp primitive type.
TypeDescriptor
🪞 Describes a Soia type.
TypeEquivalence<T, U>
🪞 A witness that two types T and U are guaranteed to be identical at runtime, even if Dart's static type checker sees them as different types.
Uint64Descriptor
🪞 Describes the uint64 primitive type.

Enums

PrimitiveType
🪞 Enumeration of all primitive types supported by Soia.
ResponseType
Response types supported by the service handler.

Constants

internal__listEquality → const ListEquality

Properties

unixEpoch DateTime
The Unix epoch timestamp (January 1, 1970, 00:00:00 UTC).
final

Functions

internal__frozenCopy<E>(Iterable<E> elements) Iterable<E>
internal__frozenMappedCopy<E extends M, M>(Iterable<M> elements, E toFrozen(M)) Iterable<E>
internal__keyedCopy<E, K>(Iterable<E> elements, String getKeySpec, K getKey(E)) KeyedIterable<E, K>
internal__keyedMappedCopy<E extends M, K, M>(Iterable<M> elements, String getKeySpec, K getKey(E), E toFrozen(M)) KeyedIterable<E, K>
internal__stringify<T>(T input, Serializer<T> serializer) String

Typedefs

HttpHeaders = Map<String, String>

Exceptions / Errors

RpcException
Exception thrown when an RPC call fails.