ReflectiveTransformer class abstract
🪞 A function object that takes in a Soia value of any type and returns a new value of the same type.
Usage: write your own implementations of this interface, and pass it to methods such as ReflectiveStructDescriptor.mapFields to recursively transform a Soia value.
See a complete example at https://github.com/gepheum/soia-dart-example/blob/main/lib/all_strings_to_upper_case.dart
Constructors
- ReflectiveTransformer()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
transform<
T> (T input, ReflectiveTypeDescriptor< T> descriptor) → T - Expects a Soia value of any type, returns a value of the same type.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- identity → const ReflectiveTransformer
- Returns values unchanged.